/* .bd-content {
    max-width: 48em !important;
} */

.wy-side-nav-search, .wy-nav-top {
    background: forestgreen;
}

.wy-nav-content {
    max-width: none;
    }

.wy-nav-content p, .wy-nav-content div.warning, dl p {
    max-width: 1000px;
}

table.docutils p {
    font-size: 0.96em !important;
}