SELECT driller_no,
       driller_class,
       driller_licence_no,
       holder_surname,
       holder_first_name,
       holder_second_name,
       wilma_transfer_no,
       wilma_creation_date,
       expiry_date,
       holder_name,
       holder_address_1,
       holder_address_2,
       holder_suburb,
       holder_state,
       holder_postcode,
       comments,
       created_by,
       creation_date,
       modified_by,
       modified_date
FROM   dhdb.dd_driller_vw 